@@ -5,10 +5,10 @@
 Tutorial 2: Two Lens Galaxies
 =============================
 
-Up to now, all the images we`ve fitted had one lens galaxy. However, we saw in chapter 1 that our lens plane can
+Up to now, all the images we've fitted had one lens galaxy. However, we saw in chapter 1 that our lens plane can
 consist of multiple galaxies which each contribute to the strong lensing. Multi-galaxy systems are challenging to
 model, because they add an extra 5-10 parameters to the non-linear search and, more problematically, the degeneracies
-between the `MassProfile``s of the two galaxies can be severe.
+between the `MassProfile`'s of the two galaxies can be severe.
 
 However, we can still break their analysis down using a pipeline and give ourselves a shot at getting a good lens
 model. Here, we`re going to fit a double lens system, fitting as much about each individual lens galaxy before fitting
@@ -16,7 +16,7 @@ them simultaneously.
 
 Up to now, I`ve put a focus on pipelines being general. The pipeline we write in this example is going to be the
 opposite, specific to the image we`re modeling. Fitting multiple lens galaxies is really difficult and writing a
-pipeline that we can generalize to many lenses isn`t currently possible with ``.yAutoLens__.
+pipeline that we can generalize to many lenses isn't currently possible with **PyAutoLens**.
 """
 
 # %%
@@ -47,9 +47,9 @@ import autolens.plot as aplt
 """
 we'll use new strong lensing data, where:
 
- - There are two lens galaxy`s whose `LightProfile``s are both `EllipticalSersic``..
- - There are two lens galaxy`s whose `MassProfile``s are both `EllipticalIsothermal``..
- - The source galaxy`s `LightProfile` is an `EllipticalExponential`.
+ - There are two lens `Galaxy`'s whose `LightProfile`'s are both `EllipticalSersic``..
+ - There are two lens `Galaxy`'s whose `MassProfile`'s are both `EllipticalIsothermal``..
+ - The source `Galaxy`'s `LightProfile` is an `EllipticalExponential`.
 """
 
 # %%
@@ -101,19 +101,19 @@ settings = al.SettingsPhaseImaging(settings_masked_imaging=settings_masked_imagi
 __Pipeline Approach__
 
 Looking at the image, there are clearly two blobs of light corresponding to our two lens galaxies. The source`s 
-light is also pretty complex - the arcs don`t posses the rotational symmetry we`re used to seeing up to now. 
+light is also pretty complex - the arcs don't posses the rotational symmetry we`re used to seeing up to now. 
 Multi-galaxy ray-tracing is just a lot more complicated, which means so is modeling it!
 
 So, how can we break the lens modeling up? As follows:
 
  1) Fit and subtract the light of each lens galaxy individually.
- 2) Use these results to initialize each lens galaxy`s `MassProfile`.
+ 2) Use these results to initialize each lens `Galaxy`'s `MassProfile`.
 
-So, with this in mind, we`ve written a pipeline composed of 4 phases:
+So, with this in mind, we've written a pipeline composed of 4 phases:
 
  1) Fit the `LightProfile` of the lens galaxy on the left of the image, at coordinates (0.0", -1.0").
  2) Fit the `LightProfile` of the lens galaxy on the right of the image, at coordinates (0.0", 1.0").
- 3) Use this lens-subtracted image to fit the source-galaxy`s light. The `MassProfile``s of the two lens 
+ 3) Use this lens-subtracted image to fit the source-`Galaxy`'s light. The `MassProfile`'s of the two lens 
  galaxies are fixed to (0.0", -1.0") and (0.0", 1.0").
  4) Fit all relevant parameters simultaneously, using priors from phases 1, 2 and 3.
 """
@@ -127,6 +127,13 @@ For this pipeline the pipeline setup customizes:
  - If there is an `ExternalShear` in the mass model or not.
 
 The pipeline setup again `tags` the output path of a pipeline.
+
+The `path_prefix` belows specify the path the pipeline results are written 
+
+ `autolens_workspace/howtolens/output/c3_t2_x2_galaxies/pipeline__light_and_source`
+
+The redshift of the lens and source galaxies are also input (see `examples/model/customize/redshift.py`) for a 
+description of what inputting redshifts into **PyAutoLens** does.
 """
 
 # %%
@@ -135,7 +142,7 @@ setup_mass = al.SetupMassTotal(no_shear=False)
 setup_source = al.SetupSourceSersic()
 
 setup = al.SetupPipeline(
-    folders=["c3_t2_x2_galaxies"],
+    path_prefix="c3_t2_x2_galaxies",
     redshift_lens=0.5,
     redshift_source=1.0,
     setup_light=setup_light,
@@ -153,10 +160,6 @@ To create a `Pipeline`, we call a `make_pipeline` function, which is written in
 
 Before we check it out, lets get the pipeline running, by importing the script, running the `make_pipeline` function
 to create the `Pipeline` object and calling that objects `run` function.
-
-The `folders` below specify the path the pipeline results are written to, which is:
-
- `autolens_workspace/output/howtolens/c3_t2_x2_galaxies/pipeline_name/setup_tag/phase_name/settings_tag`
 """
 
 # %%
@@ -178,10 +181,10 @@ Once you`ve done that, come back here and we'll wrap up this tutorial.
 # %%
 """
 And, we`re done. This pipeline takes a while to run, as is the nature of multi-galaxy modeling. Nevertheless, 
-the techniques we`ve learnt above can be applied to systems with even more `Galaxy``s albeit the increases in 
+the techniques we've learnt above can be applied to systems with even more `Galaxy`'s albeit the increases in 
 parameters will slow down the non-linear search. Here are some more Q&A`s
 
- 1) This system had two very similar lens galaxy`s with comparable amounts of light and mass. How common is this? 
+ 1) This system had two very similar lens `Galaxy`'s with comparable amounts of light and mass. How common is this? 
  Does it make it harder to model them?
 
 Typically, a 2 galaxy system has 1 massive galaxy (that makes up some 80%-90% of the overall light and mass), 
