@@ -8,7 +8,7 @@ data_name = "lens_sis__source_smooth__offset_centre"
 instrument = "vro"
 
 
-def make_pipeline(name, folders, search=af.DynestyStatic()):
+def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
     class LensPhase(al.PhaseImaging):
         def customize_priors(self, results):
 
@@ -19,7 +19,7 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
 
     phase1 = LensPhase(
         phase_name="phase_1",
-        folders=folders,
+        path_prefix=path_prefix,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.SphericalIsothermal),
             source=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
